Learn R Programming

TFORGE (version 0.1.16)

estimate_OIcov: Estimate parameters of orthogonally invariant covariance

Description

Orthogonally-invariant covariance is a restrictive structure, but if it holds then a suite of tools is available schwartzman2008inTFORGE. Any orthogonally-invariant covariance can be specified by just two parameters \(\tau\) and \(\sigma^2\). For Gaussian-distributed elements, this function estimates the parameters \(\tau\) and \(\sigma^2\) by maximum-likelihood from the data and using a maximum-likelihood estimate of the population mean @Lemma 3.3, @schwartzman2008inTFORGE.

Usage

estimate_OIcov(x, Mhat, tau = NULL)

Value

A named list of \(\sigma^2\) and \(\tau\)

Arguments

x

A single sample of symmetric matrices. x must be either an fsm object or something that as_fsm() can parse.

Mhat

A maximum-likelihood estimate of the population mean

tau

The parameter \(\tau\). If supplied only \(\sigma^2\) will be estimated.

Orthogonally-Invariant Covariance

A symmetric random matrix \(Y\) with a Gaussian distribution has orthogonally-invariant covariance if and only if \(Q Y Q^T\) has the same distribution as \(Y\) for any orthogonal matrix \(Q\).

Using the parameterisation of \(\tau\) and \(\sigma^2\) by schwartzman2008in;textualTFORGE:

  • the covariance of the off-diagonal elements of \(Y\) is \(I\sigma^2/2\) where \(I\) is the identity matrix of the correct size.

  • the covariance of the diagonal elements of \(Y\) is \(\sigma^2 (I + 1 1^T \tau/(1-\tau p) )\) where \(p\) is the number of columns of \(Y\) and \(1\) is the vector of ones.

  • the covariance between diagonal elements and non-diagonal elements is zero (i.e. they are independent).

References