Learn R Programming

TFORGE (version 0.1.16)

has_ss1: Check whether the supplied sample(s) have equal sum of squared eigenvalues

Description

Compares whether the sum of the squared eigenvalues of the supplied symmetric matrices match each other using the property that the sum of the squared eigenvalues of Y equals the trace of Y %*% Y.

Usage

has_ss1(x, tolerance = sqrt(.Machine$double.eps))

Value

TRUE or FALSE

Arguments

x

A sample or multiple samples of matrices suitable for as_flat().

tolerance

Tolerance on the relative difference, passed to all.equal()