Learn R Programming

TFORGE (version 0.1.16)

test_unconstrained_aGOE: Two Sample Test of Equal Eigenvalues Using GOE Approximation

Description

Applies the equal-eigenvalue hypothesis test between two samples by schwartzman2010gr;textualTFORGE. The null hypothesis is that the population means of each sample have the same eigenvalues, regardless of eigenvectors. The test uses a statistic from the situation that both populations are Gaussian Orthogonal Ensembles (Gaussian-distributed independent elements with the variance on the off diagonal elements half that of the diagonal elements). The distribution of this statistic for more general populations is approximated using a tangent space and the Welch-Satterthwaite approximation.

Usage

test_unconstrained_aGOE(
  x,
  x2 = NULL,
  B = "chisq",
  nullevals = "av",
  scalestat = TRUE
)

Value

A TFORGE object (see boot_calib() or chisq_calib()) including p-value of the test (slot pval) and the statistic for x (slot t0). The returned object contains further slots specific to this test:

  • a Plug-in estimate of the \(a\) in the final equation of @Section 2.4, @schwartzman2010grTFORGE.

  • v Plug-in estimate of the \(v\) in the final equation of @Section 2.4, @schwartzman2010grTFORGE.

  • var_Lambda_evals The variance of the eigenvalues of Schwartzman et al \(\Lambda\) matrix, which may relate to the quality of the Welch-Satterthwaite approximation.

Arguments

x

A single sample of matrices (passed to as_fsm()) or a list of two samples of matrices (passed to as_kfsm()).

x2

If x is a single sample then x2 must be the second sample. Otherwise x2 should be NULL.

B

Number of bootstrap samples. If B = 'chisq' then a chi-squared calibration is used instead.

nullevals

For internal testing of bootstrap calibration. "av" assumes the eigenvalues under the null hypothesis are the average of the eigenvalues of the two sample means. "1" and "2" assume the null eigenvalues are equal to the eigenvalue of the first and second sample respectively.

scalestat

If TRUE then the statistic is divided by the estimated \(a\). This modified statistic has approximately the same scale regardless of the data, although the thickness of the distribution tails (related to \(v\)) will vary. Simulations and bootstrapping behaviour more generally suggests that scalestat=TRUE leads to better test size and power when using bootstrap calibration.

Details

The test statistic is equation 11 of schwartzman2010grTFORGE. For chi-squared calibration, the \(p\) value of the test is computed using the scaled chi-squared distribution reached at the end of @Section 2.4, @schwartzman2010grTFORGE. This distribution approximates the distribution of the test statistic and the scale \(a\) and degrees of freedom \(v\) are estimated from the data.

References