For a random symmetric matrix Y, calculates the covariance of the eigenvalues of Y using the covariance of the elements of Y and the eigenvectors of the mean of Y.
cov_evals(evecs, mcov)A symmetric matrix with same number of columns as evecs.
Matrix with columns that are eigenvectors of the mean of Y.
Covariance of vech(Y), where Y is the random matrix.
For any two columns \(a\) and \(b\) of evecs, computes the covariance
$$
\textrm{Cov}(a^\top Y a, b^\top Y b) = ( a \otimes a)^\top \mathbb{D} C_0 \mathbb{D}^\top (b \otimes b),
$$
where \(a\) and \(b\) are the columns of evecs and \(C_0\)=mcov is the covariance of vech\((Y)\). \(\mathbb{D}\) and \(\otimes\) is the duplication matrix and Kronecker product respectively.
The returned matrix has rows and columns that are in the same order as the columns of evecs.
When the eigenvalues are distinct, then passing estimated eigenvectors to cov_evals() yields an estimate of the asymptotic covariance of the eigenvalues.
See Supplement B.2 for more information and derivation.