Compares whether the sum of the squared eigenvalues of the supplied symmetric matrices match each other using the property that the sum of the squared eigenvalues of Y equals the trace of Y %*% Y.
has_ss1(x, tolerance = sqrt(.Machine$double.eps))TRUE or FALSE
A sample or multiple samples of matrices suitable for as_flat().
Tolerance on the relative difference, passed to all.equal()