Given a sample from a population of symmetric matrices with Gaussian-distributed elements and orthogonally-invariant covariance, corollary 4.3 by schwartzman2008in;textualTFORGE provides a method to test the eigenvalue multiplicity of the mean matrix.
Orthogonally-invariant covariance is a strong assumption and may not be valid; consider using test_multiplicity() if you are unsure.
test_multiplicity_OI(x, mult, B = "chisq", refbasis = NULL)A TFORGE object (see boot_calib() or chisq_calib()) including p-value of the test (slot pval) and the statistic for x (slot t0).
A sample of matrices suitable for as_fsm().
A vector specifying the eigenvalue multiplicity under the null hypothesis in descending order of eigenvalue size.
Number of bootstrap samples. If B = 'chisq' then a chi-squared calibration is used instead.
Ignored (for compatibility with test_multiplicity()).
The orthogonally invariant covariance matrix is estimated by estimate_OIcov(). The maximum-likelihood estimate of the population mean under the null hypothesis is computed according to @Theorem 4.2, @schwartzman2008inTFORGE.